=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2006-02-21 22:30:22 +0000
+++ bzrlib/lockdir.py	2006-02-21 22:33:25 +0000
@@ -216,6 +216,10 @@
         """
         if self._lock_held:
             raise AssertionError("can't break own lock: %r" % self)
+        lock_info = self.peek()
+        if lock_info is None:
+            # must have been recently released
+            return
         tmpname = '%s.broken.%s.tmp' % (self.path, rand_chars(20))
         self.transport.rename(self.path, tmpname)
         self.transport.delete(tmpname + self.INFO_NAME)

=== modified file 'bzrlib/tests/test_lockdir.py'
--- bzrlib/tests/test_lockdir.py	2006-02-21 22:30:22 +0000
+++ bzrlib/tests/test_lockdir.py	2006-02-21 22:33:25 +0000
@@ -230,3 +230,20 @@
         # now we should be able to take it
         lf2.attempt_lock()
         lf2.confirm()
+
+    def test_44_break_already_released(self):
+        """Lock break races with regular release"""
+        t = self.get_transport()
+        lf1 = LockDir(t, 'test_lock')
+        lf1.attempt_lock()
+        # someone else sees it's still locked
+        lf2 = LockDir(t, 'test_lock')
+        holder_info = lf2.peek()
+        # in the interim the lock is released
+        lf1.unlock()
+        # break should succeed
+        lf2.force_break()
+        # now we should be able to take it
+        lf2.attempt_lock()
+        lf2.confirm()
+

